Module: SolidusPromotions::InMemoryOrderUpdaterPatch

Defined in:
app/patches/models/solidus_promotions/in_memory_order_updater_patch.rb

Instance Method Summary collapse

Instance Method Details

#recalculate(persist: true) ⇒ Object

This is only needed for stores upgrading from the legacy promotion system. Once we've removed support for the legacy promotion system, we can remove this.



7
8
9
10
11
12
# File 'app/patches/models/solidus_promotions/in_memory_order_updater_patch.rb', line 7

def recalculate(persist: true)
  if SolidusPromotions.config.sync_order_promotions
    MigrationSupport::OrderPromotionSyncer.new(order: order).call
  end
  super
end