Module: SolidusPromotions::OrderRecalculatorPatch
- Defined in:
- app/patches/models/solidus_promotions/order_recalculator_patch.rb
Instance Method Summary collapse
-
#recalculate ⇒ Object
This is only needed for stores upgrading from the legacy promotion system.
Instance Method Details
#recalculate ⇒ Object
This is only needed for stores upgrading from the legacy promotion system. Once we’ve removed support for the legacy promotion system, we can remove this.
7 8 9 10 11 12 |
# File 'app/patches/models/solidus_promotions/order_recalculator_patch.rb', line 7 def recalculate if SolidusPromotions.config.sync_order_promotions MigrationSupport::OrderPromotionSyncer.new(order: order).call end super end |